@@ -50,5 +50,4 @@ def to_topic(messages, topic=None, b64encode=False):
     publisher = pubsub_v1.PublisherClient()
     topic = topic or os.environ["GCF_UTILS_PUBSUB_TOPIC"]
 
-    futures = [publisher.publish(topic, _encode(data, b64encode)) for data in messages]
-    _ = [future.result() for future in futures]
+    return [publisher.publish(topic, _encode(data, b64encode)) for data in messages]
